'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._527 import ActiveProfileRangeCalculationSource
    from ._528 import AxialShaverRedressing
    from ._529 import ConventionalShavingDynamics
    from ._530 import ConventionalShavingDynamicsCalculationForDesignedGears
    from ._531 import ConventionalShavingDynamicsCalculationForHobbedGears
    from ._532 import ConventionalShavingDynamicsViewModel
    from ._533 import PlungeShaverDynamics
    from ._534 import PlungeShaverDynamicSettings
    from ._535 import PlungeShaverRedressing
    from ._536 import PlungeShavingDynamicsCalculationForDesignedGears
    from ._537 import PlungeShavingDynamicsCalculationForHobbedGears
    from ._538 import PlungeShavingDynamicsViewModel
    from ._539 import RedressingSettings
    from ._540 import RollAngleRangeRelativeToAccuracy
    from ._541 import RollAngleReportObject
    from ._542 import ShaverRedressing
    from ._543 import ShavingDynamics
    from ._544 import ShavingDynamicsCalculation
    from ._545 import ShavingDynamicsCalculationForDesignedGears
    from ._546 import ShavingDynamicsCalculationForHobbedGears
    from ._547 import ShavingDynamicsConfiguration
    from ._548 import ShavingDynamicsViewModel
    from ._549 import ShavingDynamicsViewModelBase
